.. _installation:

Installation
============

You can install bebi103 using pip. ::

	$ pip install --upgrade bebi103


Dependencies
------------

bebi103 has the following dependencies.

- Python 3.9 or newer
- NumPy_
- SciPy_
- Pandas_
- Polars_
- Numba_
- tqdm_
- CmdStanPy_ 1.0.0 or higher
- xarray_
- ArviZ_ 0.16.0 or higher
- Bokeh_ 3.4.0 or higher
- Matplotlib_
- colorcet_
- HoloViews_


.. _NumPy: http://www.numpy.org/
.. _SciPy: http://www.scipy.org/
.. _Pandas: https://pandas.pydata.org
.. _Polars: https://pola.rs
.. _Numba: http://numba.pydata.org/
.. _tqdm: https://tqdm.github.io/
.. _CmdStanPy: https://cmdstanpy.readthedocs.io/
.. _xarray: http://xarray.pydata.org/
.. _ArviZ: https://arviz-devs.github.io/arviz/
.. _Bokeh: https://docs.bokeh.org/
.. _Matplotlib: https://matplotlib.org/
.. _colorcet: https://colorcet.holoviz.org/
.. _HoloViews: http://holoviews.org/
.. _PyStan: https://pystan.readthedocs.io/
.. _Datashader: https://datashader.org/